@@ -21,6 +21,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "data/data_session.h"
 #include "lang/lang_keys.h"
 #include "main/main_session.h"
+#include "settings/settings_common.h"
 #include "window/window_session_controller.h"
 #include "styles/style_layers.h"
 #include "styles/style_boxes.h"
@@ -132,6 +133,7 @@ public:
 	void toggleProgress(bool shown);
 
 	rpl::producer<> clearRequests() const;
+	[[nodiscard]] not_null<Ui::RoundButton*> clearButton() const;
 
 protected:
 	int resizeGetHeight(int newWidth) override;
@@ -210,6 +212,10 @@ rpl::producer<> LocalStorageBox::Row::clearRequests() const {
 	return _clear->clicks() | rpl::to_empty;
 }
 
+not_null<Ui::RoundButton*> LocalStorageBox::Row::clearButton() const {
+	return _clear.data();
+}
+
 int LocalStorageBox::Row::resizeGetHeight(int newWidth) {
 	const auto height = st::localStorageRowHeight;
 	const auto padding = st::localStorageRowPadding;
@@ -281,10 +287,13 @@ LocalStorageBox::LocalStorageBox(
 	_timeLimit = settings.totalTimeLimit;
 }
 
-void LocalStorageBox::Show(not_null<Window::SessionController*> controller) {
+void LocalStorageBox::Show(
+		not_null<Window::SessionController*> controller,
+		const QString &highlightId) {
 	auto shared = std::make_shared<object_ptr<LocalStorageBox>>(
 		Box<LocalStorageBox>(&controller->session(), CreateTag()));
 	const auto weak = shared->data();
+	weak->_highlightId = highlightId;
 	rpl::combine(
 		controller->session().data().cache().statsOnMain(),
 		controller->session().data().cacheBigFile().statsOnMain()
@@ -306,6 +315,26 @@ void LocalStorageBox::prepare() {
 	setupControls();
 }
 
+void LocalStorageBox::showFinished() {
+	if (_highlightId.isEmpty()) {
+		return;
+	}
+	if (_highlightId == u"storage/clear-cache"_q) {
+		if (const auto i = _rows.find(0); i != _rows.end()) {
+			Settings::HighlightWidget(
+				i->second->entity()->clearButton(),
+				{ .rippleShape = true });
+		}
+	} else if (_highlightId == u"storage/max-cache"_q) {
+		if (_totalSlider) {
+			const auto add = st::roundRadiusSmall;
+			Settings::HighlightWidget(
+				_totalSlider,
+				{ .margin = { -add, -add, -add, -add }, .radius = add });
+		}
+	}
+}
+
 void LocalStorageBox::updateRow(
 		not_null<Ui::SlideWrap<Row>*> row,
 		const Database::TaggedSummary *data) {
