@@ -8,12 +8,14 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "boxes/star_gift_resale_box.h"
 
 #include "boxes/star_gift_box.h"
+#include "boxes/transfer_gift_box.h"
 #include "chat_helpers/compose/compose_show.h"
 #include "core/ui_integration.h"
 #include "data/stickers/data_custom_emoji.h"
 #include "data/data_peer.h"
 #include "data/data_session.h"
 #include "data/data_star_gift.h"
+#include "data/data_user.h"
 #include "lang/lang_keys.h"
 #include "info/peer_gifts/info_peer_gifts_common.h"
 #include "main/main_session.h"
@@ -23,6 +25,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "ui/toast/toast.h"
 #include "ui/widgets/buttons.h"
 #include "ui/widgets/popup_menu.h"
+#include "ui/wrap/slide_wrap.h"
 #include "ui/painter.h"
 #include "ui/ui_utility.h"
 #include "window/window_session_controller.h"
@@ -81,7 +84,6 @@ struct ResaleTabs {
 };
 [[nodiscard]] ResaleTabs MakeResaleTabs(
 		std::shared_ptr<ChatHelpers::Show> show,
-		not_null<PeerData*> peer,
 		const ResaleGiftsDescriptor &info,
 		rpl::producer<ResaleGiftsFilter> filter) {
 	auto widget = object_ptr<RpWidget>((QWidget*)nullptr);
@@ -107,9 +109,29 @@ struct ResaleTabs {
 	};
 	const auto state = raw->lifetime().make_state<State>();
 	state->filter = std::move(filter);
+
+	const auto forCraft = state->filter.current().forCraft;
+	const auto wrapName = [=](QString name, int count) {
+		auto result = tr::marked(name);
+		if (!forCraft) {
+			result.append(' ').append(tr::bold(
+				Lang::FormatCountDecimal(count)));
+		}
+		return result;
+	};
+
 	state->lists.backdrops = info.backdrops;
 	state->lists.models = info.models;
 	state->lists.patterns = info.patterns;
+	if (forCraft) {
+		using namespace Data;
+		const auto isRare = [](const UniqueGiftModelCount &entry) {
+			return entry.model.rarityType() != UniqueGiftRarity::Default;
+		};
+		state->lists.models.erase(
+			ranges::remove_if(state->lists.models, isRare),
+			end(state->lists.models));
+	}
 
 	const auto scroll = [=] {
 		return QPoint(int(base::SafeRound(state->scroll)), 0);
@@ -263,11 +285,9 @@ struct ResaleTabs {
 			if (type == GiftAttributeIdType::Model) {
 				for (auto &entry : state->lists.models) {
 					const auto id = IdFor(entry.model);
-					const auto text = TextWithEntities{
-						entry.model.name
-					}.append(' ').append(tr::bold(
-						Lang::FormatCountDecimal(entry.count)
-					));
+					const auto text = wrapName(
+						entry.model.name,
+						entry.count);
 					actionWithDocument(text, [=] {
 						toggle(id);
 					}, id.value, checked(id));
@@ -275,11 +295,9 @@ struct ResaleTabs {
 			} else if (type == GiftAttributeIdType::Backdrop) {
 				for (auto &entry : state->lists.backdrops) {
 					const auto id = IdFor(entry.backdrop);
-					const auto text = TextWithEntities{
-						entry.backdrop.name
-					}.append(' ').append(tr::bold(
-						Lang::FormatCountDecimal(entry.count)
-					));
+					const auto text = wrapName(
+						entry.backdrop.name,
+						entry.count);
 					actionWithColor(text, [=] {
 						toggle(id);
 					}, entry.backdrop.centerColor, checked(id));
@@ -287,11 +305,9 @@ struct ResaleTabs {
 			} else if (type == GiftAttributeIdType::Pattern) {
 				for (auto &entry : state->lists.patterns) {
 					const auto id = IdFor(entry.pattern);
-					const auto text = TextWithEntities{
-						entry.pattern.name
-					}.append(' ').append(tr::bold(
-						Lang::FormatCountDecimal(entry.count)
-					));
+					const auto text = wrapName(
+						entry.pattern.name,
+						entry.count);
 					actionWithDocument(text, [=] {
 						toggle(id);
 					}, id.value, checked(id));
@@ -470,16 +486,13 @@ void GiftResaleBox(
 		ResaleGiftsDescriptor descriptor) {
 	box->setWidth(st::boxWideWidth);
 
-	// Create a proper vertical layout for the title
 	const auto titleWrap = box->setPinnedToTopContent(
 		object_ptr<Ui::VerticalLayout>(box.get()));
 
-	// Add vertical spacing above the title
 	titleWrap->add(object_ptr<Ui::FixedHeightWidget>(
 		titleWrap,
 		st::defaultVerticalListSkip));
 
-	// Add the gift name with semibold style
 	titleWrap->add(
 		object_ptr<Ui::FlatLabel>(
 			titleWrap,
@@ -487,7 +500,6 @@ void GiftResaleBox(
 			st::boxTitle),
 		QMargins(st::boxRowPadding.left(), 0, st::boxRowPadding.right(), 0));
 
-	// Add the count text in gray below with proper translation
 	const auto countLabel = titleWrap->add(
 		object_ptr<Ui::FlatLabel>(
 			titleWrap,
@@ -506,22 +518,16 @@ void GiftResaleBox(
 	}, content->lifetime());
 
 	struct State {
-		rpl::event_stream<> updated;
-		ResaleGiftsDescriptor data;
-		rpl::variable<ResaleGiftsFilter> filter;
 		rpl::variable<bool> ton;
-		rpl::lifetime loading;
 		int lastMinHeight = 0;
 	};
 	const auto state = content->lifetime().make_state<State>();
-	state->data = std::move(descriptor);
 
 	box->addButton(tr::lng_create_group_back(), [=] { box->closeBox(); });
 
 #ifndef OS_MAC_STORE
 	const auto currency = box->addLeftButton(rpl::single(QString()), [=] {
 		state->ton = !state->ton.current();
-		state->updated.fire({});
 	});
 	currency->setText(rpl::conditional(
 		state->ton.value(),
@@ -536,18 +542,62 @@ void GiftResaleBox(
 		}
 	}, content->lifetime());
 
+	AddResaleGiftsList(
+		window,
+		peer,
+		content,
+		std::move(descriptor),
+		state->ton.value());
+}
+
+} // namespace
+
+void AddResaleGiftsList(
+		not_null<Window::SessionController*> window,
+		not_null<PeerData*> peer,
+		not_null<VerticalLayout*> container,
+		Data::ResaleGiftsDescriptor descriptor,
+		rpl::producer<bool> forceTon,
+		Fn<void(std::shared_ptr<Data::UniqueGift>)> bought,
+		bool forCraft) {
+	struct State {
+		rpl::event_stream<> updated;
+		ResaleGiftsDescriptor data;
+		rpl::variable<ResaleGiftsFilter> filter;
+		rpl::variable<bool> ton;
+		rpl::variable<bool> empty = true;
+		rpl::lifetime loading;
+		int lastMinHeight = 0;
+	};
+	const auto state = container->lifetime().make_state<State>();
+	state->filter = ResaleGiftsFilter{ .forCraft = forCraft };
+	state->data = std::move(descriptor);
+	state->ton = std::move(forceTon);
+
 	auto tabs = MakeResaleTabs(
 		window->uiShow(),
-		peer,
 		state->data,
 		state->filter.value());
 	state->filter = std::move(tabs.filter);
-	content->add(std::move(tabs.widget));
+	if (forCraft) {
+		const auto skip = st::giftBoxResaleTabsMargin.top()
+			- st::giftBoxTabsMargin.bottom();
+		const auto wrap = container->add(object_ptr<PaddingWrap<>>(
+			container,
+			std::move(tabs.widget),
+			QMargins(0, 0, 0, skip)));
+		wrap->paintOn([=](QPainter &p) {
+			p.fillRect(wrap->rect(), st::windowBgOver);
+		});
+	} else {
+		container->add(std::move(tabs.widget));
+	}
 
+	const auto session = &window->session();
 	state->filter.changes() | rpl::on_next([=](ResaleGiftsFilter value) {
 		state->data.offset = QString();
 		state->loading = ResaleGiftsSlice(
-			&peer->session(),
+			session,
 			state->data.giftId,
 			value,
 			QString()
@@ -559,9 +609,9 @@ void GiftResaleBox(
 			state->data.list = std::move(slice.list);
 			state->updated.fire({});
 		});
-	}, content->lifetime());
+	}, container->lifetime());
 
-	peer->owner().giftUpdates(
+	session->data().giftUpdates(
 	) | rpl::on_next([=](const Data::GiftUpdate &update) {
 		using Action = Data::GiftUpdate::Action;
 		const auto action = update.action;
@@ -581,26 +631,52 @@ void GiftResaleBox(
 			state->data.list.erase(i);
 		}
 		state->updated.fire({});
-	}, box->lifetime());
+	}, container->lifetime());
 
-	content->add(MakeGiftsSendList(window, peer, rpl::single(
+	using Descriptor = Info::PeerGifts::GiftDescriptor;
+	auto customHandler = Fn<void(Descriptor)>();
+	if (bought) {
+		using StarGift = Info::PeerGifts::GiftTypeStars;
+		customHandler = crl::guard(container, [=](Descriptor descriptor) {
+			Expects(v::is<StarGift>(descriptor));
+
+			const auto unique = v::get<StarGift>(descriptor).info.unique;
+			const auto done = crl::guard(container, [=](bool ok) {
+				if (ok) {
+					bought(unique);
+				}
+			});
+			const auto to = peer->session().user();
+			const auto ton = state->ton.current();
+			ShowBuyResaleGiftBox(window->uiShow(), unique, ton, to, done);
+		});
+	}
+
+	auto gifts = rpl::single(
 		rpl::empty
-	) | rpl::then(
-		state->updated.events()
-	) | rpl::map([=] {
+	) | rpl::then(rpl::merge(
+		state->updated.events() | rpl::type_erased,
+		state->ton.changes() | rpl::to_empty | rpl::type_erased
+	)) | rpl::map([=] {
 		auto result = GiftsDescriptor();
 		const auto selfId = window->session().userPeerId();
 		const auto forceTon = state->ton.current();
 		for (const auto &gift : state->data.list) {
+			const auto mine = (gift.unique->ownerId == selfId);
+			if (mine && forCraft) {
+				continue;
+			}
 			result.list.push_back(Info::PeerGifts::GiftTypeStars{
 				.info = gift,
 				.forceTon = forceTon,
 				.resale = true,
-				.mine = (gift.unique->ownerId == selfId),
-			});
+				.mine = mine,
+				});
 		}
+		state->empty = result.list.empty();
 		return result;
-	}), [=] {
+	});
+	const auto loadMore = [=] {
 		if (!state->data.offset.isEmpty()
 			&& !state->loading) {
 			state->loading = ResaleGiftsSlice(
@@ -620,17 +696,48 @@ void GiftResaleBox(
 				state->updated.fire({});
 			});
 		}
+	};
+	container->add(MakeGiftsList({
+		.window = window,
+		.mode = forCraft ? GiftsListMode::CraftResale : GiftsListMode::Send,
+		.peer = peer,
+		.gifts = std::move(gifts),
+		.loadMore = loadMore,
+		.handler = customHandler,
 	}));
-}
 
-} // namespace
+	const auto skip = st::defaultSubsectionTitlePadding.top();
+	const auto wrap = container->add(
+		object_ptr<SlideWrap<FlatLabel>>(
+			container,
+			object_ptr<FlatLabel>(
+				container,
+				tr::lng_gift_craft_search_none(),
+				st::craftYourListEmpty),
+			(st::boxRowPadding + QMargins(0, 0, 0, skip))),
+		style::al_top);
+	state->empty.value() | rpl::on_next([=](bool empty) {
+		// Scroll doesn't jump up if we show before rows are cleared,
+		// and we hide after rows are added.
+		if (empty) {
+			wrap->show(anim::type::instant);
+		} else {
+			crl::on_main(wrap, [=] {
+				if (!state->empty.current()) {
+					wrap->hide(anim::type::instant);
+				}
+			});
+		}
+	}, wrap->lifetime());
+	wrap->entity()->setTryMakeSimilarLines(true);
+}
 
 void ShowResaleGiftBoughtToast(
 		std::shared_ptr<Main::SessionShow> show,
 		not_null<PeerData*> to,
 		const Data::UniqueGift &gift) {
 	show->showToast({
-		.title = tr::lng_gift_sent_title(tr::now),
+		.title = to->isSelf() ? QString() : tr::lng_gift_sent_title(tr::now),
 		.text = TextWithEntities{ (to->isSelf()
 			? tr::lng_gift_sent_resale_done_self(
 				tr::now,
