@@ -228,7 +228,7 @@ FieldAutocomplete::FieldAutocomplete(
 	_inner->setGeometry(rect());
 
 	_inner->scrollToRequested(
-	) | rpl::start_with_next([=](Inner::ScrollTo data) {
+	) | rpl::on_next([=](Inner::ScrollTo data) {
 		_scroll->scrollToY(data.top, data.bottom);
 	}, lifetime());
 
@@ -238,7 +238,7 @@ FieldAutocomplete::FieldAutocomplete(
 	hide();
 
 	_scroll->geometryChanged(
-	) | rpl::start_with_next(crl::guard(_inner, [=] {
+	) | rpl::on_next(crl::guard(_inner, [=] {
 		_inner->onParentGeometryChanged();
 	}), lifetime());
 }
@@ -910,12 +910,12 @@ FieldAutocomplete::Inner::Inner(
 , _premiumMark(_session, st::stickersPremiumLock)
 , _previewTimer([=] { showPreview(); }) {
 	_session->downloaderTaskFinished(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		update();
 	}, lifetime());
 
 	_show->adjustShadowLeft(
-	) | rpl::start_with_next([=](bool adjust) {
+	) | rpl::on_next([=](bool adjust) {
 		_adjustShadowLeft = adjust;
 		update();
 	}, lifetime());
@@ -1488,7 +1488,7 @@ void FieldAutocomplete::Inner::setupLottie(StickerSuggestion &suggestion) {
 		getLottieRenderer());
 
 	suggestion.lottie->updates(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		repaintSticker(document);
 	}, _stickersLifetime);
 }
@@ -1662,10 +1662,9 @@ void InitFieldAutocomplete(
 	const auto field = descriptor.field;
 
 	field->rawTextEdit()->installEventFilter(raw);
-	field->customTab(true);
 
 	raw->mentionChosen(
-	) | rpl::start_with_next([=](FieldAutocomplete::MentionChosen data) {
+	) | rpl::on_next([=](FieldAutocomplete::MentionChosen data) {
 		const auto user = data.user;
 		if (data.mention.isEmpty()) {
 			field->insertTag(
@@ -1680,7 +1679,7 @@ void InitFieldAutocomplete(
 	const auto setText = descriptor.setText;
 
 	raw->hashtagChosen(
-	) | rpl::start_with_next([=](FieldAutocomplete::HashtagChosen data) {
+	) | rpl::on_next([=](FieldAutocomplete::HashtagChosen data) {
 		field->insertTag(data.hashtag);
 	}, raw->lifetime());
 
@@ -1691,7 +1690,7 @@ void InitFieldAutocomplete(
 		? &peer->owner().shortcutMessages()
 		: nullptr;
 	raw->botCommandChosen(
-	) | rpl::start_with_next([=](FieldAutocomplete::BotCommandChosen data) {
+	) | rpl::on_next([=](FieldAutocomplete::BotCommandChosen data) {
 		if (!features().autocompleteCommands) {
 			return;
 		}
@@ -1715,7 +1714,7 @@ void InitFieldAutocomplete(
 
 	if (const auto stickerChoosing = descriptor.stickerChoosing) {
 		raw->choosingProcesses(
-		) | rpl::start_with_next([=](FieldAutocomplete::Type type) {
+		) | rpl::on_next([=](FieldAutocomplete::Type type) {
 			if (type == FieldAutocomplete::Type::Stickers) {
 				stickerChoosing();
 			}
@@ -1723,13 +1722,14 @@ void InitFieldAutocomplete(
 	}
 	if (const auto chosen = descriptor.stickerChosen) {
 		raw->stickerChosen(
-		) | rpl::start_with_next(chosen, raw->lifetime());
+		) | rpl::on_next(chosen, raw->lifetime());
 	}
 
 	field->tabbed(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=](not_null<bool*> handled) {
 		if (!raw->isHidden()) {
 			raw->chooseSelected(FieldAutocomplete::ChooseMethod::ByTab);
+			*handled = true;
 		}
 	}, raw->lifetime());
 
@@ -1772,15 +1772,15 @@ void InitFieldAutocomplete(
 	};
 
 	raw->refreshRequests(
-	) | rpl::start_with_next(check, raw->lifetime());
+	) | rpl::on_next(check, raw->lifetime());
 
 	raw->stickersUpdateRequests(
-	) | rpl::start_with_next(updateStickersByEmoji, raw->lifetime());
+	) | rpl::on_next(updateStickersByEmoji, raw->lifetime());
 
 	peer->owner().botCommandsChanges(
 	) | rpl::filter([=](not_null<PeerData*> changed) {
 		return (peer == changed);
-	}) | rpl::start_with_next([=] {
+	}) | rpl::on_next([=] {
 		if (raw->clearFilteredBotCommands()) {
 			check();
 		}
@@ -1788,7 +1788,7 @@ void InitFieldAutocomplete(
 
 	peer->owner().stickers().updated(
 		Data::StickersType::Stickers
-	) | rpl::start_with_next(updateStickersByEmoji, raw->lifetime());
+	) | rpl::on_next(updateStickersByEmoji, raw->lifetime());
 
 	QObject::connect(
 		field->rawTextEdit(),
@@ -1797,7 +1797,7 @@ void InitFieldAutocomplete(
 		check,
 		Qt::QueuedConnection);
 
-	field->changes() | rpl::start_with_next(
+	field->changes() | rpl::on_next(
 		updateStickersByEmoji,
 		raw->lifetime());
 
@@ -1805,11 +1805,11 @@ void InitFieldAutocomplete(
 		Data::PeerUpdate::Flag::Rights
 	) | rpl::filter([=](const Data::PeerUpdate &update) {
 		return (update.peer == peer);
-	}) | rpl::start_with_next(updateStickersByEmoji, raw->lifetime());
+	}) | rpl::on_next(updateStickersByEmoji, raw->lifetime());
 
 	if (shortcutMessages) {
 		shortcutMessages->shortcutsChanged(
-		) | rpl::start_with_next(check, raw->lifetime());
+		) | rpl::on_next(check, raw->lifetime());
 	}
 
 	raw->setSendMenuDetails(std::move(descriptor.sendMenuDetails));
