@@ -45,7 +45,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "mainwindow.h"
 #include "main/main_session.h"
 #include "settings/settings_common.h"
-#include "settings/settings_premium.h"
+#include "settings/sections/settings_premium.h"
 #include "styles/style_layers.h"
 #include "styles/style_boxes.h"
 #include "styles/style_chat.h"
@@ -183,11 +183,11 @@ void EditLinkBox(
 			tr::lng_formatting_link_url(),
 			link));
 	url->heightValue(
-	) | rpl::start_with_next([placeholder](int height) {
+	) | rpl::on_next([placeholder](int height) {
 		placeholder->resize(placeholder->width(), height);
 	}, placeholder->lifetime());
 	placeholder->widthValue(
-	) | rpl::start_with_next([=](int width) {
+	) | rpl::on_next([=](int width) {
 		url->resize(width, url->height());
 	}, placeholder->lifetime());
 	url->move(placeholder->pos());
@@ -210,11 +210,11 @@ void EditLinkBox(
 	};
 
 	text->submits(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		url->setFocusFast();
 	}, text->lifetime());
 	url->submits(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		if (text->getLastText().isEmpty()) {
 			text->setFocusFast();
 		} else {
@@ -244,9 +244,6 @@ void EditLinkBox(
 		}
 	});
 
-	url->customTab(true);
-	text->customTab(true);
-
 	const auto clearFullSelection = [=](not_null<Ui::InputField*> input) {
 		if (input->empty()) {
 			return;
@@ -262,17 +259,20 @@ void EditLinkBox(
 	};
 
 	url->tabbed(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=](not_null<bool*> handled) {
 		clearFullSelection(url);
 		text->setFocus();
+		*handled = true;
 	}, url->lifetime());
+
 	text->tabbed(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=](not_null<bool*> handled) {
 		if (!url->empty()) {
 			url->selectAll();
 		}
 		clearFullSelection(text);
 		url->setFocus();
+		*handled = true;
 	}, text->lifetime());
 }
 
@@ -314,7 +314,7 @@ void EditCodeLanguageBox(
 		}
 	};
 	field->submits(
-	) | rpl::start_with_next(callback, field->lifetime());
+	) | rpl::on_next(callback, field->lifetime());
 	box->addButton(tr::lng_settings_save(), callback);
 	box->addButton(tr::lng_cancel(), [=] {
 		box->closeBox();
@@ -496,7 +496,7 @@ void InitMessageFieldHandlers(MessageFieldHandlersArgs &&args) {
 				return url.startsWith(start) ? url : (start + url);
 			}
 			show->showToast(
-				tr::lng_factcheck_links(tr::now, Ui::Text::RichLangValue));
+				tr::lng_factcheck_links(tr::now, tr::rich));
 			return QString();
 		};
 		if (action == EditLinkAction::Check) {
@@ -686,12 +686,12 @@ void InitMessageFieldFade(
 	};
 	generateFade();
 	style::PaletteChanged(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		generateFade();
 	}, topFade->lifetime());
 
 	field->sizeValue(
-	) | rpl::start_with_next_done([=](const QSize &size) {
+	) | rpl::on_next_done([=](const QSize &size) {
 		topFade->resizeToWidth(size.width());
 		bottomFade->resizeToWidth(size.width());
 		bottomFade->move(
@@ -707,7 +707,7 @@ void InitMessageFieldFade(
 		field->changes(),
 		field->scrollTop().changes() | rpl::to_empty,
 		field->sizeValue() | rpl::to_empty
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		// InputField::changes fires before the auto-resize is being applied,
 		// so for the scroll values to be accurate we enqueue the check.
 		InvokeQueued(field, [=] {
@@ -879,7 +879,7 @@ MessageLinksParser::MessageLinksParser(not_null<Ui::InputField*> field)
 : _field(field)
 , _timer([=] { parse(); }) {
 	_lifetime = _field->changes(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		const auto length = _field->getTextWithTags().text.size();
 		if (!length) {
 			_lastLength = 0;
@@ -1133,14 +1133,14 @@ base::unique_qptr<Ui::RpWidget> CreateDisabledFieldView(
 			+ customFontMarginTop, 0, 0);
 
 	raw->widthValue(
-	) | rpl::start_with_next([=](int width) {
+	) | rpl::on_next([=](int width) {
 		const auto available = width - margins.left() - margins.right();
 		const auto skip = st::historySendDisabledIconSkip;
 		label->resizeToWidth(available - skip);
 		label->moveToLeft(margins.left() + skip, margins.top(), width);
 	}, label->lifetime());
 	raw->paintRequest(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		auto p = QPainter(raw);
 		const auto &icon = st::historySendDisabledIcon;
 		icon.paint(
@@ -1208,11 +1208,11 @@ std::unique_ptr<Ui::RpWidget> TextErrorSendRestriction(
 		text,
 		st::historySendPremiumRequired);
 	label->setAttribute(Qt::WA_TransparentForMouseEvents);
-	raw->paintRequest() | rpl::start_with_next([=](QRect clip) {
+	raw->paintRequest() | rpl::on_next([=](QRect clip) {
 		QPainter(raw).fillRect(clip, st::windowBg);
 	}, raw->lifetime());
 	raw->sizeValue(
-	) | rpl::start_with_next([=](QSize size) {
+	) | rpl::on_next([=](QSize size) {
 		const auto &st = st::historyComposeField;
 		const auto width = size.width();
 		const auto margins = (st.textMargins + st.placeholderMargins);
@@ -1243,11 +1243,11 @@ std::unique_ptr<Ui::RpWidget> PremiumRequiredSendRestriction(
 	const auto link = CreateChild<Ui::LinkButton>(
 		result.get(),
 		tr::lng_restricted_send_non_premium_more(tr::now));
-	raw->paintRequest() | rpl::start_with_next([=](QRect clip) {
+	raw->paintRequest() | rpl::on_next([=](QRect clip) {
 		QPainter(raw).fillRect(clip, st::windowBg);
 	}, raw->lifetime());
 	raw->widthValue(
-	) | rpl::start_with_next([=](int width) {
+	) | rpl::on_next([=](int width) {
 		const auto &st = st::historyComposeField;
 		const auto margins = (st.textMargins + st.placeholderMargins);
 		const auto available = width - margins.left() - margins.right();
@@ -1308,8 +1308,8 @@ std::unique_ptr<Ui::AbstractButton> FrozenWriteRestriction(
 			? tr::lng_frozen_bar_text(
 				lt_arrow,
 				rpl::single(Ui::Text::IconEmoji(&st::textMoreIconEmoji)),
-				Ui::Text::WithEntities)
-			: tr::lng_frozen_restrict_text(Ui::Text::WithEntities)),
+				tr::marked)
+			: tr::lng_frozen_restrict_text(tr::marked)),
 		bar ? st::frozenBarSubtitle : st::frozenRestrictionSubtitle);
 	subtitle->setAttribute(Qt::WA_TransparentForMouseEvents);
 	subtitle->show();
@@ -1317,14 +1317,14 @@ std::unique_ptr<Ui::AbstractButton> FrozenWriteRestriction(
 	const auto shadow = bar ? CreateChild<PlainShadow>(raw) : nullptr;
 	const auto icon = bar ? CreateChild<RpWidget>(raw) : nullptr;
 	if (icon) {
-		icon->paintRequest() | rpl::start_with_next([=] {
+		icon->paintRequest() | rpl::on_next([=] {
 			auto p = QPainter(icon);
 			st::menuIconDisableAttention.paintInCenter(p, icon->rect());
 		}, icon->lifetime());
 		icon->show();
 	}
 
-	raw->sizeValue() | rpl::start_with_next([=](QSize size) {
+	raw->sizeValue() | rpl::on_next([=](QSize size) {
 		if (bar) {
 			const auto toggle = [&](auto &&widget, bool shown) {
 				if (widget->isHidden() == shown) {
@@ -1445,7 +1445,7 @@ void FrozenInfoBox(
 		raw->add(
 			object_ptr<Ui::FlatLabel>(
 				raw,
-				std::move(title) | Ui::Text::ToBold(),
+				std::move(title) | rpl::map(tr::bold),
 				st.infoTitle ? *st.infoTitle : st::defaultFlatLabel),
 			st::settingsPremiumRowTitlePadding);
 		raw->add(
@@ -1472,23 +1472,23 @@ void FrozenInfoBox(
 
 	infoRow(
 		tr::lng_frozen_subtitle1(),
-		tr::lng_frozen_text1(Ui::Text::WithEntities),
+		tr::lng_frozen_text1(tr::marked),
 		st.violationIcon ? st.violationIcon : &st::menuIconBlock);
 	infoRow(
 		tr::lng_frozen_subtitle2(),
-		tr::lng_frozen_text2(Ui::Text::WithEntities),
+		tr::lng_frozen_text2(tr::marked),
 		st.readOnlyIcon ? st.readOnlyIcon : &st::menuIconLock);
 	infoRow(
 		tr::lng_frozen_subtitle3(),
 		tr::lng_frozen_text3(
 			lt_link,
-			rpl::single(Ui::Text::Link(u"@SpamBot"_q, info.appealUrl)),
+			rpl::single(tr::link(u"@SpamBot"_q, info.appealUrl)),
 			lt_date,
 			rpl::single(TextWithEntities{
 				langDayOfMonthFull(
 					base::unixtime::parse(info.until).date()),
 			}),
-			Ui::Text::WithEntities),
+			tr::marked),
 		st.appealIcon ? st.appealIcon : &st::menuIconHourglass);
 
 	const auto button = box->addButton(
@@ -1500,7 +1500,7 @@ void FrozenInfoBox(
 		- buttonPadding.right();
 	button->widthValue() | rpl::filter([=] {
 		return (button->widthNoMargins() != buttonWidth);
-	}) | rpl::start_with_next([=] {
+	}) | rpl::on_next([=] {
 		button->resizeToWidth(buttonWidth);
 	}, button->lifetime());
 }
