@@ -155,6 +155,8 @@ QByteArray Settings::serialize() const {
 	LogPosition(_mediaViewPosition, u"Viewer"_q);
 	const auto ivPosition = Serialize(_ivPosition);
 	LogPosition(_ivPosition, u"IV"_q);
+	const auto callPanelPosition = Serialize(_callPanelPosition);
+	LogPosition(_callPanelPosition, u"CallPanel"_q);
 	const auto proxy = _proxy.serialize();
 	const auto skipLanguages = _skipTranslationLanguages.current();
 
@@ -242,7 +244,8 @@ QByteArray Settings::serialize() const {
 		+ Serialize::bytearraySize(_tonsiteStorageToken)
 		+ sizeof(qint32) * 8
 		+ sizeof(ushort)
-		+ sizeof(qint32); // _notificationsDisplayChecksum
+		+ sizeof(qint32) // _notificationsDisplayChecksum
+		+ Serialize::bytearraySize(callPanelPosition);
 
 	auto result = QByteArray();
 	result.reserve(size);
@@ -406,7 +409,8 @@ QByteArray Settings::serialize() const {
 			<< qint32(_systemDarkModeEnabled.current() ? 1 : 0)
 			<< qint32(_quickDialogAction)
 			<< _notificationsVolume
-			<< _notificationsDisplayChecksum;
+			<< _notificationsDisplayChecksum
+			<< callPanelPosition;
 	}
 
 	Ensures(result.size() == size);
@@ -527,6 +531,7 @@ void Settings::addFromSerialized(const QByteArray &serialized) {
 	qint32 trayIconMonochrome = (_trayIconMonochrome.current() ? 1 : 0);
 	qint32 ttlVoiceClickTooltipHidden = _ttlVoiceClickTooltipHidden.current() ? 1 : 0;
 	QByteArray ivPosition;
+	QByteArray callPanelPosition;
 	QString customFontFamily = _customFontFamily;
 	qint32 systemUnlockEnabled = _systemUnlockEnabled ? 1 : 0;
 	qint32 weatherInCelsius = !_weatherInCelsius ? 0 : *_weatherInCelsius ? 1 : 2;
@@ -875,6 +880,9 @@ void Settings::addFromSerialized(const QByteArray &serialized) {
 	if (!stream.atEnd()) {
 		stream >> notificationsDisplayChecksum;
 	}
+	if (!stream.atEnd()) {
+		stream >> callPanelPosition;
+	}
 	if (stream.status() != QDataStream::Ok) {
 		LOG(("App Error: "
 			"Bad data for Core::Settings::constructFromSerialized()"));
@@ -1086,6 +1094,9 @@ void Settings::addFromSerialized(const QByteArray &serialized) {
 	if (!ivPosition.isEmpty()) {
 		_ivPosition = Deserialize(ivPosition);
 	}
+	if (!callPanelPosition.isEmpty()) {
+		_callPanelPosition = Deserialize(callPanelPosition);
+	}
 	_customFontFamily = customFontFamily;
 	_systemUnlockEnabled = (systemUnlockEnabled == 1);
 	_weatherInCelsius = !weatherInCelsius
