@@ -738,6 +738,14 @@ struct ActionSuggestBirthday {
 	Birthday birthday;
 };
 
+struct ActionNewCreatorPending {
+	UserId newCreatorId = 0;
+};
+
+struct ActionChangeCreator {
+	UserId newCreatorId = 0;
+};
+
 struct ServiceAction {
 	std::variant<
 		v::null_t,
@@ -791,7 +799,9 @@ struct ServiceAction {
 		ActionSuggestedPostApproval,
 		ActionSuggestedPostSuccess,
 		ActionSuggestedPostRefund,
-		ActionSuggestBirthday> content;
+		ActionSuggestBirthday,
+		ActionNewCreatorPending,
+		ActionChangeCreator> content;
 };
 
 ServiceAction ParseServiceAction(
