@@ -743,6 +743,14 @@ QByteArray SerializeMessage(
 		if (const auto year = data.birthday.year()) {
 			push("year", year);
 		}
+	}, [&](const ActionNewCreatorPending &data) {
+		pushActor();
+		pushAction("new_creator_pending");
+		pushBare("new_creator", wrapUserName(data.newCreatorId));
+	}, [&](const ActionChangeCreator &data) {
+		pushActor();
+		pushAction("change_creator");
+		pushBare("new_creator", wrapUserName(data.newCreatorId));
 	}, [](v::null_t) {});
 
 	if (v::is_null(message.action.content)) {
@@ -752,6 +760,7 @@ QByteArray SerializeMessage(
 			pushBare(
 				"forwarded_from",
 				wrapPeerName(message.forwardedFromId));
+			push("forwarded_from_id", message.forwardedFromId);
 		} else if (!message.forwardedFromName.isEmpty()) {
 			pushBare(
 				"forwarded_from",
@@ -1318,6 +1327,34 @@ Result JsonWriter::writeStoriesEnd() {
 	return _output->writeBlock(popNesting());
 }
 
+Result JsonWriter::writeProfileMusicStart(const Data::ProfileMusicInfo &data) {
+	Expects(_output != nullptr);
+
+	auto block = prepareObjectItemStart("profile_music");
+	return _output->writeBlock(block + pushNesting(Context::kArray));
+}
+
+Result JsonWriter::writeProfileMusicSlice(const Data::ProfileMusicSlice &data) {
+	Expects(_output != nullptr);
+
+	if (data.list.empty()) {
+		return Result::Success();
+	}
+
+	auto block = QByteArray();
+	for (const auto &message : data.list) {
+		block.append(prepareArrayItemStart());
+		block.append(SerializeMessage(_context, message, {}, QString()));
+	}
+	return _output->writeBlock(block);
+}
+
+Result JsonWriter::writeProfileMusicEnd() {
+	Expects(_output != nullptr);
+
+	return _output->writeBlock(popNesting());
+}
+
 Result JsonWriter::writeContactsList(const Data::ContactsList &data) {
 	Expects(_output != nullptr);
 
