@@ -499,6 +499,9 @@ TTLButton::TTLButton(
 		}
 
 	}, lifetime());
+	setAccessibleName((recordingVideo
+		? tr::lng_in_dlg_video_message_ttl
+		: tr::lng_in_dlg_voice_message_ttl)(tr::now));
 }
 
 void TTLButton::clearState() {
@@ -607,6 +610,7 @@ ListenWrap::ListenWrap(
 , _inactiveWaveformBar(
 	anim::with_alpha(_activeWaveformBar, kInactiveWaveformBarAlpha))
 , _playPause(_playPauseSt, [=] { _playPauseButton->update(); }) {
+	_delete->setAccessibleName(tr::lng_record_lock_delete(tr::now));
 	init();
 }
 
@@ -755,6 +759,7 @@ void ListenWrap::initPlayButton() {
 	const auto &width = _waveformBgFinalCenterRect.height();
 	_playPauseButton->resize(width, width);
 	_playPauseButton->show();
+	_playPauseButton->setAccessibleName(tr::lng_record_lock_play(tr::now));
 
 	_playPauseButton->paintRequest(
 	) | rpl::on_next([=](const QRect &clip) {
@@ -776,6 +781,9 @@ void ListenWrap::initPlayButton() {
 	const auto showPause = _lifetime.make_state<rpl::variable<bool>>(false);
 	showPause->changes(
 	) | rpl::on_next([=](bool pause) {
+		_playPauseButton->setAccessibleName(pause
+			? tr::lng_record_lock_pause(tr::now)
+			: tr::lng_record_lock_play(tr::now));
 		_playPause.setState(pause
 			? PlayButtonLayout::State::Pause
 			: PlayButtonLayout::State::Play);
@@ -1057,6 +1065,7 @@ void RecordLock::init() {
 		}
 		drawProgress(p);
 	}, lifetime());
+	setAccessibleName(tr::lng_record_lock(tr::now));
 }
 
 void RecordLock::drawProgress(QPainter &p) {
@@ -1303,6 +1312,7 @@ CancelButton::CancelButton(
 , _width(st::historyRecordCancelButtonWidth)
 , _rippleRect(QRect(0, (height - _width) / 2, _width, _width))
 , _text(st::semiboldTextStyle, tr::lng_selected_clear(tr::now)) {
+	setAccessibleName(tr::lng_record_cancel_recording(tr::now));
 	resize(_width, height);
 	init();
 }
@@ -1620,6 +1630,9 @@ void VoiceRecordBar::init() {
 
 	_paused.value() | rpl::distinct_until_changed(
 	) | rpl::on_next([=](bool paused) {
+		_lock->setAccessibleName(paused
+			? tr::lng_record_lock_resume(tr::now)
+			: tr::lng_record_lock(tr::now));
 		if (!paused) {
 			return;
 		}
