@@ -37,8 +37,8 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "lang/lang_keys.h"
 #include "main/main_session.h"
 #include "settings/business/settings_chat_intro.h"
-#include "settings/settings_credits.h" // BuyStarsHandler
-#include "settings/settings_premium.h"
+#include "settings/sections/settings_credits.h" // BuyStarsHandler
+#include "settings/sections/settings_premium.h"
 #include "ui/chat/chat_style.h"
 #include "ui/text/custom_emoji_instance.h"
 #include "ui/text/text_utilities.h"
@@ -155,18 +155,6 @@ private:
 
 };
 
-class NewBotThreadDownIcon final : public MediaGenericPart {
-public:
-	void draw(
-		Painter &p,
-		not_null<const MediaGeneric*> owner,
-		const PaintContext &context,
-		int outerWidth) const override;
-	QSize countOptimalSize() override;
-	QSize countCurrentSize(int newWidth) override;
-
-};
-
 UserpicsList::UserpicsList(
 	std::vector<not_null<PeerData*>> peers,
 	const style::GroupCallUserpics &st,
@@ -227,26 +215,7 @@ int UserpicsList::width() const {
 	return _st.size + (shifted * (_st.size - _st.shift));
 }
 
-void NewBotThreadDownIcon::draw(
-		Painter &p,
-		not_null<const MediaGeneric*> owner,
-		const PaintContext &context,
-		int outerWidth) const {
-	auto color = context.st->msgServiceFg()->c;
-	color.setAlphaF(color.alphaF() * kLabelOpacity);
-	st::newBotThreadDown.paintInCenter(
-		p,
-		QRect(0, 0, outerWidth, st::newBotThreadDown.height()),
-		color);
-}
 
-QSize NewBotThreadDownIcon::countOptimalSize() {
-	return st::newBotThreadDown.size();
-}
-
-QSize NewBotThreadDownIcon::countCurrentSize(int newWidth) {
-	return st::newBotThreadDown.size();
-}
 
 NewBotThreadDottedLine::NewBotThreadDottedLine(not_null<Element*> parent)
 : _parent(parent) {
@@ -366,9 +335,46 @@ auto GenerateNewBotThread(
 		const auto title = tr::lng_bot_new_thread_title(tr::now);
 		const auto description = tr::lng_bot_new_thread_about(tr::now);
 		push(std::make_unique<NewBotThreadDottedLine>(parent));
+		push(std::make_unique<LambdaGenericPart>(
+			QSize(
+				st::newThreadAboutIconOuter,
+				st::newThreadAboutIconOuter + st::newThreadAboutIconSkip),
+			[=](
+				Painter &p,
+				not_null<const MediaGeneric*> owner,
+				const PaintContext &context,
+				int outerWidth) {
+					const auto size = st::newThreadAboutIconOuter;
+					const auto &icon = st::newThreadAboutIcon;
+					const auto x = (outerWidth - icon.width()) / 2;
+					const auto y = (size - icon.height()) / 2
+						+ st::newThreadAboutIconSkip;
+					p.setPen(Qt::NoPen);
+					p.setBrush(context.st->msgServiceBgSelected());
+					p.drawEllipse(
+						(outerWidth - size) / 2,
+						st::newThreadAboutIconSkip,
+						size,
+						size);
+					const auto color = context.st->msgServiceFg();
+					icon.paint(p, x, y, outerWidth, color->c);
+				}));
 		pushText(tr::bold(title), st::chatIntroTitleMargin);
 		pushText({ description }, st::chatIntroMargin);
-		push(std::make_unique<NewBotThreadDownIcon>());
+		push(std::make_unique<LambdaGenericPart>(
+			st::newBotThreadDown.size() / 4 * 3,
+			[=, h = st::newBotThreadDown.height() / 2 + st::lineWidth * 4](
+				Painter &p,
+				not_null<const MediaGeneric*> owner,
+				const PaintContext &context,
+				int outerWidth) {
+					auto color = context.st->msgServiceFg()->c;
+					color.setAlphaF(color.alphaF() * kLabelOpacity);
+					st::newBotThreadDown.paintInCenter(
+						p,
+						QRect(0, 0, outerWidth, h),
+						color);
+			}));
 
 		parent->addVerticalMargins(
 			st::newBotThreadTopSkip - st::msgServiceMargin.top(),
@@ -626,7 +632,13 @@ HistoryItem *AboutView::item() const {
 }
 
 bool AboutView::aboveHistory() const {
-	return !_history->peer->isBot() || !_history->isForum();
+	if (!_history->peer->isBot() || !_history->isForum()) {
+		return true;
+	}
+	const auto info = _history->peer->asUser()->botInfo.get();
+	return !(info->canManageTopics
+		&& info->startToken.isEmpty()
+		&& (!_history->isEmpty() || _history->lastMessage()));
 }
 
 bool AboutView::refresh() {
@@ -683,7 +695,10 @@ bool AboutView::refresh() {
 		}
 		_version = 0;
 		return false;
-	} else if (_history->peer->isForum()) {
+	} else if (_history->peer->isForum()
+			&& info->canManageTopics
+			&& info->startToken.isEmpty()
+			&& (!_history->isEmpty() || _history->lastMessage())) {
 		if (_item) {
 			return false;
 		}
@@ -695,6 +710,14 @@ bool AboutView::refresh() {
 		return false;
 	}
 	_version = version;
+	if (_history->peer->isBot() && _history->peer->isForum()) {
+		_history->session().data().newItemAdded(
+		) | rpl::on_next([=](not_null<HistoryItem*> item) {
+			if (item->history() == _history) {
+				_destroyRequests.fire({});
+			}
+		}, lifetime());
+	}
 	setItem(makeAboutBot(info), nullptr);
 	return true;
 }
@@ -716,7 +739,7 @@ void AboutView::make(Data::ChatIntro data, bool preview) {
 			| MessageFlag::FakeHistoryItem
 			| MessageFlag::Local),
 		.from = _history->peer->id,
-	}, PreparedServiceText{ { text }});
+	}, PreparedServiceText{ { text } });
 
 	if (data.sticker) {
 		_helloChosen = nullptr;
@@ -772,6 +795,10 @@ rpl::producer<> AboutView::refreshRequests() const {
 	return _refreshRequests.events();
 }
 
+rpl::producer<> AboutView::destroyRequests() const {
+	return _destroyRequests.events();
+}
+
 rpl::lifetime &AboutView::lifetime() {
 	return _lifetime;
 }
@@ -885,7 +912,7 @@ AdminLog::OwnedItem AboutView::makeNewPeerInfo(not_null<UserData*> user) {
 			| MessageFlag::FakeHistoryItem
 			| MessageFlag::Local),
 		.from = _history->peer->id,
-	}, PreparedServiceText{ { text }});
+	}, PreparedServiceText{ { text } });
 
 	auto owned = AdminLog::OwnedItem(_delegate, item);
 	owned->overrideMedia(std::make_unique<HistoryView::MediaGeneric>(
@@ -1028,7 +1055,7 @@ AdminLog::OwnedItem AboutView::makeNewBotThread() {
 		result.get(),
 		GenerateNewBotThread(result.get(), _item.get()),
 		HistoryView::MediaGenericDescriptor{
-			.maxWidth = st::chatIntroWidth,
+			.maxWidth = st::newThreadAboutMaxWidth,
 			.service = true,
 			.hideServiceText = true,
 		}));
