@@ -26,9 +26,9 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "history/view/history_view_element.h"
 #include "lang/lang_keys.h"
 #include "main/main_session.h"
-#include "settings/settings_credits.h" // Settings::CreditsId
+#include "settings/sections/settings_credits.h" // Settings::CreditsId
 #include "settings/settings_credits_graphics.h" // GiftedCreditsBox
-#include "settings/settings_premium.h" // Settings::ShowGiftPremium
+#include "settings/sections/settings_premium.h" // Settings::ShowGiftPremium
 #include "ui/chat/chat_style.h"
 #include "ui/controls/ton_common.h" // kNanosInOne
 #include "ui/layers/generic_box.h"
@@ -69,111 +69,114 @@ QSize PremiumGift::size() {
 }
 
 TextWithEntities PremiumGift::title() {
-	using namespace Ui::Text;
 	if (tonGift()) {
 		return tr::lng_gift_ton_amount(
 			tr::now,
 			lt_count_decimal,
 			CreditsAmount(0, _data.count, CreditsType::Ton).value(),
-			Ui::Text::WithEntities);
+			tr::marked);
 	} else if (starGift()) {
 		const auto peer = _parent->history()->peer;
+		const auto to = _data.auctionTo ? _data.auctionTo : peer.get();
 		return peer->isSelf()
-			? tr::lng_action_gift_self_subtitle(tr::now, WithEntities)
+			? tr::lng_action_gift_self_subtitle(tr::now, tr::marked)
 			: (peer->isServiceUser() && _data.channelFrom)
 			? tr::lng_action_gift_got_subtitle(
 				tr::now,
 				lt_user,
-				WithEntities({})
-					.append(SingleCustomEmoji(
+				tr::marked()
+					.append(Ui::Text::SingleCustomEmoji(
 						peer->owner().customEmojiManager(
-							).peerUserpicEmojiData(_data.channelFrom)))
+						).peerUserpicEmojiData(_data.channelFrom)))
 					.append(' ')
 					.append(_data.channelFrom->shortName()),
-				WithEntities)
-			: peer->isServiceUser()
-			? tr::lng_gift_link_label_gift(tr::now, WithEntities)
+				tr::marked)
+			: (!_data.auctionTo && peer->isServiceUser())
+			? tr::lng_gift_link_label_gift(tr::now, tr::marked)
 			: (outgoingGift()
 				? tr::lng_action_gift_sent_subtitle
 				: tr::lng_action_gift_got_subtitle)(
 					tr::now,
 					lt_user,
-					WithEntities({})
-						.append(SingleCustomEmoji(
-							peer->owner().customEmojiManager(
-								).peerUserpicEmojiData(peer)))
+					tr::marked()
+						.append(Ui::Text::SingleCustomEmoji(
+							to->owner().customEmojiManager(
+							).peerUserpicEmojiData(to)))
 						.append(' ')
-						.append(peer->shortName()),
-					WithEntities);
+						.append(to->shortName()),
+					tr::marked);
 	} else if (creditsPrize()) {
-		return tr::lng_prize_title(tr::now, WithEntities);
-	} else if (const auto c = credits()) {
-		return tr::lng_gift_stars_title(tr::now, lt_count, c, WithEntities);
+		return tr::lng_prize_title(tr::now, tr::marked);
+	} else if (const auto stars = credits()) {
+		return tr::lng_gift_stars_title(tr::now, lt_count_decimal, stars, tr::marked);
 	}
 	return gift()
 		? tr::lng_action_gift_premium_months(
 			tr::now,
 			lt_count,
 			premiumMonths(),
-			WithEntities)
+			tr::marked)
 		: _data.unclaimed
-		? tr::lng_prize_unclaimed_title(tr::now, WithEntities)
-		: tr::lng_prize_title(tr::now, WithEntities);
+		? tr::lng_prize_unclaimed_title(tr::now, tr::marked)
+		: tr::lng_prize_title(tr::now, tr::marked);
 }
 
 TextWithEntities PremiumGift::author() {
-	using namespace Ui::Text;
 	if (!_data.stargiftReleasedBy) {
 		return {};
 	}
 	return tr::lng_gift_released_by(
 		tr::now,
 		lt_name,
-		Ui::Text::Link('@' + _data.stargiftReleasedBy->username()),
-		Ui::Text::WithEntities);
+		tr::link('@' + _data.stargiftReleasedBy->username()),
+		tr::marked);
 }
 
 TextWithEntities PremiumGift::subtitle() {
 	if (tonGift()) {
-		return tr::lng_action_gift_got_ton(tr::now, Ui::Text::WithEntities);
+		return tr::lng_action_gift_got_ton(tr::now, tr::marked);
 	} else if (starGift()) {
 		const auto toChannel = _data.channel
 			&& _parent->history()->peer->isServiceUser();
 		return !_data.message.empty()
 			? _data.message
 			: _data.refunded
-			? tr::lng_action_gift_refunded(tr::now, Ui::Text::RichLangValue)
+			? tr::lng_action_gift_refunded(tr::now, tr::rich)
 			: outgoingGift()
-			? (_data.starsUpgradedBySender
+			? (_data.auctionTo
+				? tr::lng_action_gift_self_auction(
+					tr::now,
+					lt_cost,
+					tr::lng_action_gift_for_stars(
+						tr::now,
+						lt_count_decimal,
+						_data.starsBid,
+						tr::marked),
+					tr::rich)
+				: _data.starsUpgradedBySender
 				? tr::lng_action_gift_sent_upgradable(
 					tr::now,
 					lt_user,
-					Ui::Text::Bold(_parent->history()->peer->shortName()),
-					Ui::Text::RichLangValue)
+					tr::bold(_parent->history()->peer->shortName()),
+					tr::rich)
 				: tr::lng_action_gift_sent_text(
 					tr::now,
-					lt_count,
+					lt_count_decimal,
 					_data.starsConverted,
 					lt_user,
-					Ui::Text::Bold(_parent->history()->peer->shortName()),
-					Ui::Text::RichLangValue))
+					tr::bold(_parent->history()->peer->shortName()),
+					tr::rich))
 			: _data.starsUpgradedBySender
-			? tr::lng_action_gift_got_upgradable_text(
-				tr::now,
-				Ui::Text::RichLangValue)
+			? tr::lng_action_gift_got_upgradable_text(tr::now, tr::rich)
 			: (_data.starsToUpgrade
 				&& !_data.converted
 				&& _parent->history()->peer->isSelf())
-			? tr::lng_action_gift_self_about_unique(
-				tr::now,
-				Ui::Text::RichLangValue)
+			? tr::lng_action_gift_self_about_unique(tr::now, tr::rich)
 			: (_data.starsToUpgrade
 				&& !_data.converted
 				&& _parent->history()->peer->isServiceUser()
 				&& _data.channel)
-			? tr::lng_action_gift_channel_about_unique(
-				tr::now,
-				Ui::Text::RichLangValue)
+			? tr::lng_action_gift_channel_about_unique(tr::now, tr::rich)
 			: (!_data.converted && !_data.starsConverted)
 			? (_data.saved
 				? (toChannel
@@ -181,9 +184,7 @@ TextWithEntities PremiumGift::subtitle() {
 					: tr::lng_action_gift_can_remove_text)
 				: (toChannel
 					? tr::lng_action_gift_got_gift_channel
-					: tr::lng_action_gift_got_gift_text))(
-						tr::now,
-						Ui::Text::RichLangValue)
+					: tr::lng_action_gift_got_gift_text))(tr::now, tr::rich)
 			: (_data.converted
 				? (toChannel
 					? tr::lng_gift_channel_got
@@ -196,7 +197,7 @@ TextWithEntities PremiumGift::subtitle() {
 					tr::now,
 					lt_count,
 					_data.starsConverted,
-					Ui::Text::RichLangValue);
+					tr::rich);
 	}
 	const auto isCreditsPrize = creditsPrize();
 	if (const auto count = credits(); count && !isCreditsPrize) {
@@ -204,15 +205,13 @@ TextWithEntities PremiumGift::subtitle() {
 			? tr::lng_gift_stars_outgoing(
 				tr::now,
 				lt_user,
-				Ui::Text::Bold(_parent->history()->peer->shortName()),
-				Ui::Text::RichLangValue)
-			: tr::lng_gift_stars_incoming(tr::now, Ui::Text::WithEntities);
+				tr::bold(_parent->history()->peer->shortName()),
+				tr::rich)
+			: tr::lng_gift_stars_incoming(tr::now, tr::marked);
 	} else if (gift()) {
 		return !_data.message.empty()
 			? _data.message
-			: tr::lng_action_gift_premium_about(
-				tr::now,
-				Ui::Text::RichLangValue);
+			: tr::lng_action_gift_premium_about(tr::now, tr::rich);
 	}
 	const auto name = _data.channel ? _data.channel->name() : "channel";
 	auto result = (_data.unclaimed
@@ -222,8 +221,8 @@ TextWithEntities PremiumGift::subtitle() {
 		: tr::lng_prize_gift_about)(
 			tr::now,
 			lt_channel,
-			Ui::Text::Bold(name),
-			Ui::Text::RichLangValue);
+			tr::bold(name),
+			tr::rich);
 	result.append("\n\n");
 	result.append(isCreditsPrize
 		? tr::lng_prize_credits(
@@ -231,10 +230,10 @@ TextWithEntities PremiumGift::subtitle() {
 			lt_amount,
 			tr::lng_prize_credits_amount(
 				tr::now,
-				lt_count,
+				lt_count_decimal,
 				credits(),
-				Ui::Text::RichLangValue),
-			Ui::Text::RichLangValue)
+				tr::marked),
+			tr::rich)
 		: (_data.unclaimed
 			? tr::lng_prize_unclaimed_duration
 			: _data.viaGiveaway
@@ -242,8 +241,8 @@ TextWithEntities PremiumGift::subtitle() {
 			: tr::lng_prize_gift_duration)(
 				tr::now,
 				lt_duration,
-				Ui::Text::Bold(GiftDuration(premiumDays())),
-				Ui::Text::RichLangValue));
+				tr::bold(GiftDuration(premiumDays())),
+				tr::rich));
 	return result;
 }
 
@@ -279,7 +278,7 @@ ClickHandlerPtr PremiumGift::createViewLink() {
 						return window->session().credits().tonLoaded();
 					}
 					return false;
-				}) | rpl::take(1) | rpl::start_with_next([=] {
+				}) | rpl::take(1) | rpl::on_next([=] {
 					if (const auto window = weak.get()) {
 						window->showSettings(Settings::CurrencyId());
 					}
@@ -362,11 +361,15 @@ void PremiumGift::draw(
 QImage PremiumGift::cornerTag(const PaintContext &context) {
 	auto badge = Info::PeerGifts::GiftBadge();
 	if (_data.unique) {
+		const auto burned = _data.unique->burned;
+		const auto burnedBg = Info::PeerGifts::BurnedBadgeBg();
 		badge = {
-			.text = tr::lng_gift_collectible_tag(tr::now),
-			.bg1 = _data.unique->backdrop.edgeColor,
-			.bg2 = _data.unique->backdrop.patternColor,
-			.fg = QColor(255, 255, 255),
+			.text = (burned
+				? tr::lng_gift_burned_tag(tr::now)
+				: tr::lng_gift_collectible_tag(tr::now)),
+			.bg1 = (burned ? burnedBg : _data.unique->backdrop.edgeColor),
+			.bg2 = (burned ? burnedBg : _data.unique->backdrop.patternColor),
+			.fg = (burned ? st::white->c : _data.unique->backdrop.textColor),
 		};
 	} else if (const auto count = _data.limitedCount) {
 		badge = {
@@ -423,12 +426,12 @@ void PremiumGift::unloadHeavyPart() {
 
 bool PremiumGift::incomingGift() const {
 	const auto out = _parent->data()->out();
-	return gift() && (starGiftUpgrade() ? out : !out);
+	return gift() && !_data.auctionTo && (starGiftUpgrade() ? out : !out);
 }
 
 bool PremiumGift::outgoingGift() const {
 	const auto out = _parent->data()->out();
-	return gift() && (starGiftUpgrade() ? !out : out);
+	return gift() && (_data.auctionTo || (starGiftUpgrade() ? !out : out));
 }
 
 bool PremiumGift::gift() const {
@@ -514,6 +517,9 @@ ClickHandlerPtr OpenStarGiftLink(not_null<HistoryItem*> item) {
 	}
 	const auto data = *gift;
 	const auto itemId = item->fullId();
+	const auto upgradedMsgId = data.upgraded
+		? data.realGiftMsgId
+		: MsgId(0);
 	const auto openInsteadId = data.realGiftMsgId
 		? Data::SavedStarGiftId::User(data.realGiftMsgId)
 		: (data.channel && data.channelSavedId)
@@ -526,6 +532,9 @@ ClickHandlerPtr OpenStarGiftLink(not_null<HistoryItem*> item) {
 		const auto controller = weak.get();
 		if (!controller) {
 			return;
+		} else if (data.unique && data.unique->burned) {
+			controller->showToast(tr::lng_gift_burned_message(tr::now));
+			return;
 		}
 		const auto quick = [=](not_null<Window::SessionController*> window) {
 			Settings::ShowStarGiftViewBox(window, data, itemId);
@@ -537,33 +546,70 @@ ClickHandlerPtr OpenStarGiftLink(not_null<HistoryItem*> item) {
 			return;
 		}
 		*requesting = true;
-		controller->session().api().request(MTPpayments_GetSavedStarGift(
-			MTP_vector<MTPInputSavedStarGift>(
-				1,
-				Api::InputSavedStarGiftId(openInsteadId))
-		)).done([=](const MTPpayments_SavedStarGifts &result) {
-			*requesting = false;
-			if (const auto window = weak.get()) {
-				const auto &data = result.data();
-				window->session().data().processUsers(data.vusers());
-				window->session().data().processChats(data.vchats());
-				const auto owner = openInsteadId.chat()
-					? openInsteadId.chat()
-					: window->session().user();
-				const auto &list = data.vgifts().v;
-				if (list.empty()) {
-					quick(window);
-				} else if (auto parsed = Api::FromTL(owner, list[0])) {
-					Settings::ShowSavedStarGiftBox(window, owner, *parsed);
+		const auto requestSavedGift = [=] {
+			controller->session().api().request(MTPpayments_GetSavedStarGift(
+				MTP_vector<MTPInputSavedStarGift>(
+					1,
+					Api::InputSavedStarGiftId(openInsteadId))
+			)).done([=](const MTPpayments_SavedStarGifts &result) {
+				*requesting = false;
+				if (const auto window = weak.get()) {
+					const auto &data = result.data();
+					window->session().data().processUsers(data.vusers());
+					window->session().data().processChats(data.vchats());
+					const auto owner = openInsteadId.chat()
+						? openInsteadId.chat()
+						: window->session().user();
+					const auto &list = data.vgifts().v;
+					if (list.empty()) {
+						quick(window);
+					} else if (auto g = Api::FromTL(owner, list[0])) {
+						Settings::ShowSavedStarGiftBox(window, owner, *g);
+					}
 				}
+			}).fail([=](const MTP::Error &error) {
+				*requesting = false;
+				if (const auto window = weak.get()) {
+					window->showToast(error.type());
+					quick(window);
+				}
+			}).send();
+		};
+		if (const auto msgId = upgradedMsgId) {
+			const auto session = &controller->session();
+			const auto owner = &controller->session().data();
+			const auto processItem = [=](not_null<HistoryItem*> item) {
+				const auto media = item->media();
+				if (!media || !media->gift() || !media->gift()->unique) {
+					*requesting = false;
+					if (const auto window = weak.get()) {
+						quick(window);
+					}
+					return;
+				}
+				// It is not possible to request a saved star gift
+				// when it is transferred and does not belong to you.
+				if (!media->gift()->transferred) {
+					return requestSavedGift();
+				}
+				*requesting = false;
+				const auto local = u"nft/"_q + media->gift()->unique->slug;
+				UrlClickHandler::Open(session->createInternalLinkFull(local));
+			};
+			if (const auto item = owner->nonChannelMessage(msgId)) {
+				processItem(item);
+			} else {
+				session->api().requestMessageData(nullptr, msgId, [=] {
+					if (const auto item = owner->nonChannelMessage(msgId)) {
+						processItem(item);
+					} else {
+						*requesting = false;
+					}
+				});
 			}
-		}).fail([=](const MTP::Error &error) {
-			*requesting = false;
-			if (const auto window = weak.get()) {
-				window->showToast(error.type());
-				quick(window);
-			}
-		}).send();
+		} else {
+			requestSavedGift();
+		}
 	});
 }
 
