@@ -20,6 +20,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "media/view/media_view_playback_controls.h"
 #include "media/view/media_view_open_common.h"
 #include "media/media_common.h"
+#include "platform/platform_text_recognition.h"
 
 class History;
 
@@ -157,6 +158,7 @@ private:
 		Share,
 		Rotate,
 		More,
+		Recognize,
 		Icon,
 		Video,
 		Caption,
@@ -284,8 +286,11 @@ private:
 	void deleteMedia();
 	void showMediaOverview();
 	void copyMedia();
+	void recognize();
 	void receiveMouse();
 	void showAttachedStickers();
+	[[nodiscard]] auto scaledRecognitionRect(QPoint position)
+	const -> std::optional<Platform::TextRecognition::RectWithText>;
 	void showDropdown();
 	void handleTouchTimer();
 	void handleDocumentClick();
@@ -297,7 +302,8 @@ private:
 	void showSaveMsgToast(const QString &path, auto phrase);
 	void showSaveMsgToastWith(
 		const QString &path,
-		const TextWithEntities &text);
+		const TextWithEntities &text,
+		crl::time duration = 0);
 	void updateSaveMsg();
 
 	void clearBeforeHide();
@@ -584,9 +590,10 @@ private:
 
 	QRect _leftNav, _leftNavOver, _leftNavIcon;
 	QRect _rightNav, _rightNavOver, _rightNavIcon;
-	QRect _headerNav, _nameNav, _dateNav;
+	QRect _headerNav, _nameNav, _dateNav, _separatorNav;
 	QRect _rotateNav, _rotateNavOver, _rotateNavIcon;
 	QRect _shareNav, _shareNavOver, _shareNavIcon;
+	QRect _recognizeNav, _recognizeNavOver, _recognizeNavIcon;
 	QRect _saveNav, _saveNavOver, _saveNavIcon;
 	QRect _moreNav, _moreNavOver, _moreNavIcon;
 	bool _leftNavVisible = false;
@@ -594,6 +601,7 @@ private:
 	bool _saveVisible = false;
 	bool _shareVisible = false;
 	bool _rotateVisible = false;
+	bool _recognizeVisible = false;
 	bool _headerHasLink = false;
 	QString _dateText;
 	QString _headerText;
@@ -754,6 +762,10 @@ private:
 
 	int _verticalWheelDelta = 0;
 
+	Platform::TextRecognition::Result _recognitionResult;
+	bool _showRecognitionResults = false;
+	Ui::Animations::Simple _recognitionAnimation;
+
 	bool _themePreviewShown = false;
 	uint64 _themePreviewId = 0;
 	QRect _themePreviewRect;
