@@ -50,7 +50,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "data/data_session.h"
 #include "main/main_session.h"
 #include "apiwrap.h"
-#include "settings/settings_premium.h"
+#include "settings/sections/settings_premium.h"
 #include "window/themes/window_theme.h"
 #include "window/section_widget.h"
 #include "styles/style_chat.h"
@@ -278,8 +278,8 @@ EffectPreview::EffectPreview(
 			this,
 			tr::lng_effect_premium(
 				lt_link,
-				tr::lng_effect_premium_link() | Ui::Text::ToLink(),
-				Ui::Text::WithEntities),
+				tr::lng_effect_premium_link(tr::link),
+				tr::marked),
 			st::effectPreviewPromoLabel),
 		st::effectPreviewPromoPadding))
 , _bottom(_send ? ((Ui::RpWidget*)_send.get()) : _premiumPromoLabel.get())
@@ -406,7 +406,7 @@ void EffectPreview::setupBackground() {
 		QImage::Format_ARGB32_Premultiplied);
 	_bg.setDevicePixelRatio(ratio);
 	repaintBackground();
-	_theme->repaintBackgroundRequests() | rpl::start_with_next([=] {
+	_theme->repaintBackgroundRequests() | rpl::on_next([=] {
 		repaintBackground();
 		update();
 	}, lifetime());
@@ -454,6 +454,7 @@ void EffectPreview::repaintBackground() {
 			_chatStyle.get(),
 			rect,
 			rect,
+			rect,
 			false);
 		context.outbg = _item->hasOutLayout();
 		_item->draw(p, context);
@@ -485,7 +486,7 @@ void EffectPreview::setupLottie() {
 	}
 	rpl::single(rpl::empty) | rpl::then(
 		_show->session().downloaderTaskFinished()
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		if (checkLoaded()) {
 			_readyCheckLifetime.destroy();
 			createLottie();
@@ -501,7 +502,7 @@ void EffectPreview::createLottie() {
 		Stickers::EffectType::MessageEffect);
 	const auto raw = _lottie.get();
 	raw->updates(
-	) | rpl::start_with_next([=](Lottie::Update update) {
+	) | rpl::on_next([=](Lottie::Update update) {
 		v::match(update.data, [&](const Lottie::Information &information) {
 		}, [&](const Lottie::DisplayFrameRequest &request) {
 			this->update();
@@ -641,7 +642,7 @@ FillMenuResult AttachSendMenuEffect(
 	}
 
 	(*selector)->chosen(
-	) | rpl::start_with_next([=](ChosenReaction chosen) {
+	) | rpl::on_next([=](ChosenReaction chosen) {
 		const auto &reactions = show->session().data().reactions();
 		const auto &effects = reactions.list(Data::Reactions::Type::Effects);
 		const auto i = ranges::find(effects, chosen.id, &Data::Reaction::id);
@@ -846,7 +847,7 @@ void SetupMenuAndShortcuts(
 	Shortcuts::Requests(
 	) | rpl::filter([=] {
 		return button->isActiveWindow();
-	}) | rpl::start_with_next([=](not_null<Shortcuts::Request*> request) {
+	}) | rpl::on_next([=](not_null<Shortcuts::Request*> request) {
 		using Command = Shortcuts::Command;
 
 		const auto now = details().type;
@@ -943,7 +944,7 @@ void SetupUnreadMentionsMenu(
 		using Flag = MTPmessages_ReadMentions::Flag;
 		peer->session().api().request(MTPmessages_ReadMentions(
 			MTP_flags(rootId ? Flag::f_top_msg_id : Flag()),
-			peer->input,
+			peer->input(),
 			MTP_int(rootId)
 		)).done([=](const MTPmessages_AffectedHistory &result) {
 			const auto offset = peer->session().api().applyAffectedHistory(
@@ -986,9 +987,9 @@ void SetupUnreadReactionsMenu(
 		peer->session().api().request(MTPmessages_ReadReactions(
 			MTP_flags((rootId ? Flag::f_top_msg_id : Flag(0))
 				| (sublist ? Flag::f_saved_peer_id : Flag(0))),
-			peer->input,
+			peer->input(),
 			MTP_int(rootId),
-			sublist ? sublist->sublistPeer()->input : MTPInputPeer()
+			sublist ? sublist->sublistPeer()->input() : MTPInputPeer()
 		)).done([=](const MTPmessages_AffectedHistory &result) {
 			const auto offset = peer->session().api().applyAffectedHistory(
 				peer,
