@@ -19,12 +19,15 @@ using Flags = base::flags<Flag>;
 
 namespace Ui {
 class GenericBox;
+class RpWidget;
 } // namespace Ui
 
 namespace Settings {
 
-void PowerSavingBox(not_null<Ui::GenericBox*> box);
+void PowerSavingBox(
+	not_null<Ui::GenericBox*> box,
+	PowerSaving::Flags highlightFlags = PowerSaving::Flags());
 
 [[nodiscard]] EditFlagsDescriptor<PowerSaving::Flags> PowerSavingLabels();
 
-} // namespace PowerSaving
+} // namespace Settings
