@@ -26,6 +26,7 @@ class InputField;
 	not_null<Ui::BoxContent*> box,
 	not_null<Window::SessionController*> controller,
 	not_null<ChatHelpers::TabbedPanel*> emojiPanel,
-	QPoint shift);
+	QPoint shift,
+	bool fadeOnFocusChange = true);
 
 } // namespace Ui
