@@ -240,7 +240,6 @@ void Bubble::paintBubble(QPainter &p, const QRect &r, const QBrush &brush) {
 		p.drawPath(bubblePath(r));
 	}
 	p.setPen(st::activeButtonFg);
-	p.setFont(_st.font);
 	const auto withSubtext = !_subtext.isEmpty();
 	const auto height = withSubtext
 		? (_st.font->height
@@ -332,7 +331,7 @@ BubbleWidget::BubbleWidget(
 
 	resizeTo(_bubble.width(), _bubble.height());
 	_bubble.widthChanges(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		resizeTo(_bubble.width(), _bubble.height());
 	}, lifetime());
 
@@ -342,9 +341,9 @@ BubbleWidget::BubbleWidget(
 	}
 	std::move(
 		showFinishes
-	) | rpl::take(1) | rpl::start_with_next([=] {
+	) | rpl::take(1) | rpl::on_next([=] {
 		_state.value(
-		) | rpl::start_with_next([=](BubbleRowState state) {
+		) | rpl::on_next([=](BubbleRowState state) {
 			animateTo(state);
 		}, lifetime());
 		if (instant) {
@@ -355,7 +354,7 @@ BubbleWidget::BubbleWidget(
 			_bubble.finishAnimating();
 		}
 
-		parent->widthValue() | rpl::start_with_next([=](int w) {
+		parent->widthValue() | rpl::on_next([=](int w) {
 			if (!_appearanceAnimation.animating()) {
 				const auto available = w
 					- _outerPadding.left()
@@ -384,7 +383,7 @@ void BubbleWidget::setupParticles(not_null<Ui::RpWidget*> parent) {
 
 	_particlesAnimation.init([=] { _particlesWidget->update(); });
 
-	_particlesWidget->paintRequest() | rpl::start_with_next([=] {
+	_particlesWidget->paintRequest() | rpl::on_next([=] {
 		if (!_particlesAnimation.animating()) {
 			_particlesAnimation.start();
 		}
@@ -411,17 +410,17 @@ void BubbleWidget::setupParticles(not_null<Ui::RpWidget*> parent) {
 
 		p.setClipPath(bubblePath);
 		_particles->setColor(st::premiumButtonFg->c);
-		_particles->paint(p, _particlesWidget->rect(), crl::now());
+		_particles->paint(p, _particlesWidget->rect(), crl::now(), false);
 		p.setClipping(false);
 
 		p.setClipPath(fullRect.subtracted(bubblePath));
 		_particles->setColor(_brushOverride
 			? st::groupCallMemberInactiveIcon->c
 			: st::creditsBg3->c);
-		_particles->paint(p, _particlesWidget->rect(), crl::now());
+		_particles->paint(p, _particlesWidget->rect(), crl::now(), false);
 	}, _particlesWidget->lifetime());
 
-	geometryValue() | rpl::start_with_next([=](QRect geometry) {
+	geometryValue() | rpl::on_next([=](QRect geometry) {
 		const auto particlesSize = QSize(
 			int(geometry.width() * 1.5),
 			int(geometry.height() * 1.5));
@@ -684,7 +683,7 @@ not_null<BubbleWidget*> AddBubbleRow(
 	rpl::combine(
 		container->sizeValue(),
 		bubble->sizeValue()
-	) | rpl::start_with_next([=](const QSize &parentSize, const QSize &size) {
+	) | rpl::on_next([=](const QSize &parentSize, const QSize &size) {
 		container->resize(parentSize.width(), size.height());
 	}, bubble->lifetime());
 	bubble->show();
