@@ -40,8 +40,11 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "main/main_session.h"
 #include "main/main_session_settings.h"
 #include "ui/text/text_utilities.h"
+#include "platform/platform_specific.h"
 
 #include <QtGui/QWindow>
+#include <QtGui/QGuiApplication>
+#include <QtGui/QScreen>
 
 #if __has_include(<gio/gio.hpp>)
 #include <gio/gio.hpp>
@@ -129,6 +132,19 @@ constexpr auto kSystemAlertDuration = crl::time(0);
 
 } // namespace
 
+const char kOptionCustomNotification[] = "custom-notification";
+
+base::options::toggle OptionCustomNotification({
+	.id = kOptionCustomNotification,
+	.name = "Force non-native notifications availability",
+	.description = "Allow to disable native notifications"
+		" even if custom notifications are broken on this platform",
+	.scope = [] {
+		return Platform::Notifications::Enforced();
+	},
+	.restartRequired = true,
+});
+
 const char kOptionGNotification[] = "gnotification";
 const char kOptionHideReplyButton[] = "hide-reply-button";
 
@@ -178,7 +194,7 @@ System::System()
 , _waitForAllGroupedTimer([=] { showGrouped(); })
 , _manager(std::make_unique<DummyManager>(this)) {
 	settingsChanged(
-	) | rpl::start_with_next([=](ChangeType type) {
+	) | rpl::on_next([=](ChangeType type) {
 		if (type == ChangeType::DesktopEnabled) {
 			clearAll();
 		} else if (type == ChangeType::ViewParams) {
@@ -205,7 +221,7 @@ void System::setManager(Fn<std::unique_ptr<Manager>()> create) {
 	});
 
 	if ((Core::App().settings().nativeNotifications()
-				|| Platform::Notifications::Enforced())
+				|| nativeEnforced())
 			&& Platform::Notifications::Supported()) {
 		if (_manager->type() == ManagerType::Native) {
 			return;
@@ -217,7 +233,7 @@ void System::setManager(Fn<std::unique_ptr<Manager>()> create) {
 		}
 	}
 
-	if (Platform::Notifications::Enforced()) {
+	if (nativeEnforced()) {
 		if (_manager->type() != ManagerType::Dummy) {
 			_manager = std::make_unique<DummyManager>(this);
 		}
@@ -235,6 +251,10 @@ rpl::producer<> System::managerChanged() const {
 	return _managerChanged.events();
 }
 
+bool System::nativeEnforced() const {
+	return !OptionCustomNotification.value() && Platform::Notifications::Enforced();
+}
+
 Main::Session *System::findSession(uint64 sessionId) const {
 	for (const auto &[index, account] : Core::App().domain().accounts()) {
 		if (const auto session = account->maybeSession()) {
@@ -270,7 +290,9 @@ System::SkipState System::skipNotification(
 	const auto item = notification.item;
 	const auto type = notification.type;
 	const auto messageType = (type == Data::ItemNotificationType::Message);
-	if (!item->notificationThread()->currentNotification()
+	const auto thread = item->maybeNotificationThread();
+	if (!thread
+		|| !thread->currentNotification()
 		|| (messageType && item->skipNotification())
 		|| (type == Data::ItemNotificationType::Reaction
 			&& skipReactionNotification(item))) {
@@ -367,7 +389,7 @@ void System::registerThread(not_null<Data::Thread*> thread) {
 	if (const auto topic = thread->asTopic()) {
 		const auto &[i, ok] = _watchedTopics.emplace(topic, rpl::lifetime());
 		if (ok) {
-			topic->destroyed() | rpl::start_with_next([=] {
+			topic->destroyed() | rpl::on_next([=] {
 				clearFromTopic(topic);
 			}, i->second);
 		}
@@ -376,7 +398,7 @@ void System::registerThread(not_null<Data::Thread*> thread) {
 			sublist,
 			rpl::lifetime());
 		if (ok) {
-			sublist->destroyed() | rpl::start_with_next([=] {
+			sublist->destroyed() | rpl::on_next([=] {
 				clearFromSublist(sublist);
 			}, i->second);
 		}
@@ -1088,7 +1110,7 @@ TextWithEntities Manager::ComposeReactionNotification(
 			tr::now,
 			lt_reaction,
 			reactionWithEntities,
-			Ui::Text::WithEntities);
+			tr::marked);
 	};
 	if (hideContent) {
 		return simple(tr::lng_reaction_notext);
@@ -1101,7 +1123,7 @@ TextWithEntities Manager::ComposeReactionNotification(
 			reactionWithEntities,
 			lt_text,
 			item->notificationText(),
-			Ui::Text::WithEntities);
+			tr::marked);
 	};
 	if (!media || media->webpage()) {
 		return text();
@@ -1122,8 +1144,8 @@ TextWithEntities Manager::ComposeReactionNotification(
 				lt_reaction,
 				reactionWithEntities,
 				lt_emoji,
-				Ui::Text::WithEntities(sticker->alt),
-				Ui::Text::WithEntities);
+				tr::marked(sticker->alt),
+				tr::marked);
 		}
 		return simple(tr::lng_reaction_document);
 	} else if (const auto contact = media->sharedContact()) {
@@ -1142,8 +1164,8 @@ TextWithEntities Manager::ComposeReactionNotification(
 			lt_reaction,
 			reactionWithEntities,
 			lt_name,
-			Ui::Text::WithEntities(name),
-			Ui::Text::WithEntities);
+			tr::marked(name),
+			tr::marked);
 	} else if (media->location()) {
 		return simple(tr::lng_reaction_location);
 		// lng_reaction_live_location not used right now :(
@@ -1156,7 +1178,7 @@ TextWithEntities Manager::ComposeReactionNotification(
 				reactionWithEntities,
 				lt_title,
 				poll->question,
-				Ui::Text::WithEntities);
+				tr::marked);
 	} else if (media->game()) {
 		return simple(tr::lng_reaction_game);
 	} else if (media->invoice()) {
@@ -1229,7 +1251,7 @@ void Manager::notificationActivated(
 					.topicRootId = topicRootId,
 					.monoforumPeerId = monoforumPeerId,
 				},
-				SuggestPostOptions(),
+				SuggestOptions(),
 				MessageCursor{
 					length,
 					length,
@@ -1281,7 +1303,7 @@ Window::SessionController *Manager::openNotificationMessage(
 
 	const auto separateId = !topic
 		? Window::SeparateId(history->peer)
-		: history->peer->asChannel()->useSubsectionTabs()
+		: history->peer->useSubsectionTabs()
 		? Window::SeparateId(Window::SeparateType::Chat, topic)
 		: Window::SeparateId(Window::SeparateType::Forum, history);
 	const auto separate = Core::App().separateWindowFor(separateId);
@@ -1479,5 +1501,27 @@ QString WrapFromScheduled(const QString &text) {
 	return QString::fromUtf8("\xF0\x9F\x93\x85 ") + text;
 }
 
+QRect NotificationDisplayRect(Window::Controller *controller) {
+	const auto displayChecksum
+		= Core::App().settings().notificationsDisplayChecksum();
+
+	auto screen = (QScreen*)(nullptr);
+	if (displayChecksum) {
+		using namespace Platform;
+		for (const auto candidateScreen : QGuiApplication::screens()) {
+			if (ScreenNameChecksum(candidateScreen) == displayChecksum) {
+				screen = candidateScreen;
+				break;
+			}
+		}
+	}
+
+	return screen
+		? screen->availableGeometry()
+		: controller
+		? controller->widget()->desktopRect()
+		: QGuiApplication::primaryScreen()->availableGeometry();
+}
+
 } // namespace Notifications
 } // namespace Window
